==> nextcloud-10.0.2.tar.bz2: nextcloud/apps/files/l10n/sv.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Lagring är tillfälligt inte tillgänglig",
    "Storage invalid" : "Lagring ogiltig",
    "Unknown error" : "Okänt fel",
    "Files" : "Filer",
    "All files" : "Alla filer",
    "Recent" : "Nyligen",
    "File could not be found" : "Fil kunde inte hittas",
    "Home" : "Hem",
    "Close" : "Stäng",
    "Favorites" : "Favoriter",
    "Could not create folder \"{dir}\"" : "Kunde inte skapa mapp \"{dir}\"",
    "Upload cancelled." : "Uppladdning avbruten.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan inte ladda upp {filename} eftersom den antingen är en mapp eller har 0 bytes.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Inte tillräckligt med ledigt utrymme, du laddar upp {size1} men endast {size2} finns kvar.",
    "Target folder \"{dir}\" does not exist any more" : "Målmapp \"{dir}\" existerar inte mer",
    "Not enough free space" : "Inte tillräckligt med ledigt utrymme",
    "Uploading..." : "Laddar upp...",
    "..." : "...",
    "{hours}:{minutes}:{seconds} hour{plural_s} left" : "{hours}:{minutes}:{seconds} timme/ar kvar",
    "{hours}:{minutes}h" : "{hours}:{minutes}",
    "{minutes}:{seconds} minute{plural_s} left" : "{minutes}:{seconds} minut(er) kvar",
    "{minutes}:{seconds}m" : "{minutes}:{seconds}",
    "{seconds} second{plural_s} left" : "{seconds} sekund(er) kvar",
    "{seconds}s" : "{seconds}s",
    "Any moment now..." : "Alldeles strax...",
    "Soon..." : "Snart...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} av {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Filuppladdning pågår. Lämnar du sidan så avbryts uppladdningen.",
    "Actions" : "Åtgärder",
    "Download" : "Ladda ner",
    "Rename" : "Byt namn",
    "Move" : "Flytta",
    "Target folder" : "Målmapp",
    "Delete" : "Radera",
    "Disconnect storage" : "Koppla bort lagring",
    "Unshare" : "Sluta dela",
    "Details" : "Detaljer",
    "Select" : "Välj",
    "Pending" : "Väntar",
    "Unable to determine date" : "Misslyckades avgöra datum",
    "This operation is forbidden" : "Denna operation är förbjuden",
    "This directory is unavailable, please check the logs or contact the administrator" : "Denna katalog är inte tillgänglig, kontrollera loggarna eller kontakta administratören",
    "Could not move \"{file}\", target exists" : "Kunde inte flytta \"{file}\", filen existerar redan",
    "Could not move \"{file}\"" : "Kunde inte flytta \"{file}\"",
    "{newName} already exists" : "{newName} existerar redan",
    "Could not rename \"{fileName}\", it does not exist any more" : "Kunde inte döpa om \"{fileName}\", filen existerar inte mer",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Namnet \"{targetName}\" används redan i mappen \"{dir}\". Vänligen välj ett annat namn.",
    "Could not rename \"{fileName}\"" : "Kan inte döpa om \"{fileName}\"",
    "Could not create file \"{file}\"" : "Kunde inte skapa fil \"{fileName}\"",
    "Could not create file \"{file}\" because it already exists" : "Kunde inte skapa fil \"{file}\" därför att den redan existerar",
    "Could not create folder \"{dir}\" because it already exists" : "Kunde inte skapa \"{dir}\" därför att den redan existerar",
    "Error deleting file \"{fileName}\"." : "Fel när \"{fileName}\" skulle raderas.",
    "No search results in other folders for '{tag}{filter}{endtag}'" : "Inga sökresultat hittades i andra mappar för '{tag}{filter}{endtag}'",
    "Name" : "Namn",
    "Size" : "Storlek",
    "Modified" : "Ändrad",
    "_%n folder_::_%n folders_" : ["%n mapp","%n mappar"],
    "_%n file_::_%n files_" : ["%n fil","%n filer"],
    "{dirs} and {files}" : "{dirs} och {files}",
    "_including %n hidden_::_including %n hidden_" : ["inkluderar %n gömd","inkluderar %n gömda"],
    "You don’t have permission to upload or create files here" : "Du har ej tillåtelse att ladda upp eller skapa filer här",
    "_Uploading %n file_::_Uploading %n files_" : ["Laddar upp %n fil","Laddar upp %n filer"],
    "New" : "Ny",
    "\"{name}\" is an invalid file name." : "\"{name}\" är ett ogiltligt filnamn.",
    "File name cannot be empty." : "Filnamn kan inte vara tomt.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Lagring av {owner}  är full, filer kan inte uppdateras eller synkroniseras längre!",
    "Your storage is full, files can not be updated or synced anymore!" : "Ditt lagringsutrymme är fullt, filer kan inte längre uppdateras eller synkroniseras!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Lagring av  {owner}  är nästan full  ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Ditt lagringsutrymme är nästan fullt ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["matchar '{filter}'","matcha '{filter}'"],
    "View in folder" : "Utforska i mapp",
    "Path" : "sökväg",
    "_%n byte_::_%n bytes_" : ["%n bytes","%n bytes"],
    "Favorited" : "Favoriserad",
    "Favorite" : "Favorit",
    "Copy local link" : "Kopiera lokal länk",
    "Folder" : "Mapp",
    "New folder" : "Ny mapp",
    "Upload" : "Ladda upp",
    "An error occurred while trying to update the tags" : "Ett fel uppstod när uppdatera taggarna",
    "File changes" : "Filändringar",
    "Created by {user}" : "Skapad av {user}",
    "Changed by {user}" : "Ändrad av {user}",
    "Deleted by {user}" : "Raderad av {user}",
    "Restored by {user}" : "Återställd av {user}",
    "Renamed by {user}" : "Filnamn ändrat av {user}",
    "Moved by {user}" : "Flyttad av {user}",
    "You created {file}" : "Du skapade {file}",
    "{user} created {file}" : "{user} skapade {file}",
    "{file} was created in a public folder" : "{file} skapades i en publik mapp",
    "You changed {file}" : "Du ändrade {file}",
    "{user} changed {file}" : "{user} ändrade {file}",
    "You deleted {file}" : "Du raderade {file}",
    "{user} deleted {file}" : "{user} raderade {file}",
    "You restored {file}" : "Du återställde {file}",
    "{user} restored {file}" : "{user} återställde {file}",
    "You renamed {oldfile} to {newfile}" : "Du ändrade filnamn {oldfile} till {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} ändrade filnamn {oldfile} till {newfile}",
    "You moved {oldfile} to {newfile}" : "Du flyttade {oldfile} till {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} flyttade {oldfile} till {newfile}",
    "A new file or folder has been <strong>created</strong>" : "En ny fil eller mapp har blivit <strong>skapad</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Begränsa notiser om skapande och ändringar till dina <strong>favoritfiler</strong> <em>(Endast ström)</em>",
    "Upload (max. %s)" : "Ladda upp (max. %s)",
    "File handling" : "Filhantering",
    "Maximum upload size" : "Maximal storlek att ladda upp",
    "max. possible: " : "max. möjligt:",
    "Save" : "Spara",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Med PHP-FPM kan det ta cirka 5 minuter för ändringarna att träda i kraft.",
    "Missing permissions to edit from here." : "Saknar rättigheter att ändra härifrån.",
    "Settings" : "Inställningar",
    "Show hidden files" : "Visa dolda filer",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Använd den här adressen för att <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">komma åt dina filer via WebDAV</a>",
    "No files in here" : "Inga filer kunde hittas",
    "Upload some content or sync with your devices!" : "Ladda upp innehåll eller synkronisera med dina enheter!",
    "No entries found in this folder" : "Inget innehåll hittades i denna mapp",
    "Select all" : "Välj allt",
    "Upload too large" : "För stor uppladdning",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Filerna du försöker ladda upp överstiger den maximala storleken för filöverföringar på servern.",
    "No favorites" : "Inga favoriter",
    "Files and folders you mark as favorite will show up here" : "Filer och mappar du markerat som favoriter kommer att visas här",
    "Shared with you" : "Delad med dig",
    "Shared with others" : "Delad med andra",
    "Shared by link" : "Delad via länk",
    "Tags" : "Taggar",
    "Deleted files" : "Raderade filer",
    "Text file" : "Textfil",
    "New text file.txt" : "nytextfil.txt",
    "Storage not available" : "Lagring inte tillgänglig",
    "Unable to set upload directory." : "Kan inte sätta mapp för uppladdning.",
    "Invalid Token" : "Ogiltig token",
    "No file was uploaded. Unknown error" : "Ingen fil uppladdad. Okänt fel",
    "There is no error, the file uploaded with success" : "Inga fel uppstod. Filen laddades upp utan problem.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Den uppladdade filen överskrider upload_max_filesize direktivet php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Den uppladdade filen överskrider MAX_FILE_SIZE direktivet som har angetts i HTML formuläret",
    "The uploaded file was only partially uploaded" : "Den uppladdade filen var endast delvis uppladdad",
    "No file was uploaded" : "Ingen fil laddades upp",
    "Missing a temporary folder" : "En temporär mapp saknas",
    "Failed to write to disk" : "Misslyckades spara till disk",
    "Not enough storage available" : "Inte tillräckligt med lagringsutrymme tillgängligt",
    "The target folder has been moved or deleted." : "Målmappen har flyttats eller tagits bort.",
    "Upload failed. Could not find uploaded file" : "Uppladdning misslyckades. Kunde inte hitta den uppladdade filen",
    "Upload failed. Could not get file info." : "Uppladdning misslyckades. Gick inte att hämta filinformation.",
    "Invalid directory." : "Felaktig mapp.",
    "Total file size {size1} exceeds upload limit {size2}" : "Totala filstorleken {size1} överskrider uppladdningsgränsen {size2}",
    "Error uploading file \"{fileName}\": {message}" : "Fel vid uppladdning av fil \"{fileName}\": {message}",
    "Could not get result from server." : "Gick inte att hämta resultat från server.",
    "No entries in this folder match '{filter}'" : "Inga poster i denna mapp match \"{filter}\"",
    "Local link" : "Lokal länk",
    "{newname} already exists" : "{newname}  existerar redan",
    "A file or folder has been <strong>changed</strong>" : "En ny fil eller mapp har blivit <strong>ändrad</strong>",
    "A file or folder has been <strong>deleted</strong>" : "En ny fil eller mapp har blivit <strong>raderad</strong>",
    "A file or folder has been <strong>restored</strong>" : "En ny fil eller mapp har blivit <strong>återskapad</strong>",
    "You created %1$s" : "Du skapade %1$s",
    "%2$s created %1$s" : "%2$s skapade %1$s",
    "%1$s was created in a public folder" : "%1$s skapades i en publik mapp",
    "You changed %1$s" : "Du ändrade %1$s",
    "%2$s changed %1$s" : "%2$s ändrade %1$s",
    "You deleted %1$s" : "Du raderade %1$s",
    "%2$s deleted %1$s" : "%2$s raderade %1$s",
    "You restored %1$s" : "Du återkapade %1$s",
    "%2$s restored %1$s" : "%2$s återskapade %1$s",
    "Changed by %2$s" : "Ändrad av %2$s",
    "Deleted by %2$s" : "Bortagen av %2$s",
    "Restored by %2$s" : "Återställd av %2$s",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Använd denna adress för att <a href=\"%s\" target=\"_blank\">få tillgång till filer via WebDAV</a>",
    "Cancel upload" : "Avbryt uppladdning"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.5.tar.bz2: nextcloud/apps/files/l10n/sv.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Lagring är tillfälligt inte tillgänglig",
    "Storage invalid" : "Lagring ogiltig",
    "Unknown error" : "Okänt fel",
    "All files" : "Alla filer",
    "Recent" : "Senaste",
    "File could not be found" : "Fil kunde inte hittas",
    "Home" : "Hem",
    "Close" : "Stäng",
    "Favorites" : "Favoriter",
    "Could not create folder \"{dir}\"" : "Kunde inte skapa mapp \"{dir}\"",
    "Upload cancelled." : "Uppladdning avbruten.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan inte ladda upp {filename} eftersom den antingen är en mapp eller har 0 bytes.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Inte tillräckligt med ledigt utrymme, du laddar upp {size1} men endast {size2} finns kvar.",
    "Target folder \"{dir}\" does not exist any more" : "Målmapp \"{dir}\" existerar inte mer",
    "Not enough free space" : "Inte tillräckligt med ledigt utrymme",
    "Uploading …" : "Laddar upp ..",
    "…" : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} av {totalSize} ({bitrate})",
    "Target folder does not exist any more" : "Målmapp existerar inte längre",
    "Actions" : "Åtgärder",
    "Download" : "Ladda ned",
    "Rename" : "Byt namn",
    "Move or copy" : "Flytta eller kopiera",
    "Target folder" : "Målmapp",
    "Delete" : "Radera",
    "Disconnect storage" : "Koppla bort lagring",
    "Unshare" : "Sluta dela",
    "Could not load info for file \"{file}\"" : "Kunde inte ladda information för fil \"{file}\"",
    "Files" : "Filer",
    "Details" : "Detaljer",
    "Select" : "Välj",
    "Pending" : "Väntar",
    "Unable to determine date" : "Misslyckades avgöra datum",
    "This operation is forbidden" : "Denna operation är förbjuden",
    "This directory is unavailable, please check the logs or contact the administrator" : "Denna katalog är inte tillgänglig, kontrollera loggarna eller kontakta administratören",
    "Could not move \"{file}\", target exists" : "Kunde inte flytta \"{file}\", filen existerar redan",
    "Could not move \"{file}\"" : "Kunde inte flytta \"{file}\"",
    "Could not copy \"{file}\", target exists" : "Kunde inte kopiera \"{file}\", filen existerar redan",
    "Could not copy \"{file}\"" : "Kunde inte kopiera \"{file}\"",
    "Copied {origin} inside {destination}" : "Kopierade {origin} till {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Kopierade {origin} och {nbfiles} andra filer i {destination}",
    "{newName} already exists" : "{newName} existerar redan",
    "Could not rename \"{fileName}\", it does not exist any more" : "Kunde inte döpa om \"{fileName}\", filen existerar inte mer",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Namnet \"{targetName}\" används redan i mappen \"{dir}\". Vänligen välj ett annat namn.",
    "Could not rename \"{fileName}\"" : "Kan inte döpa om \"{fileName}\"",
    "Could not create file \"{file}\"" : "Kunde inte skapa fil \"{fileName}\"",
    "Could not create file \"{file}\" because it already exists" : "Kunde inte skapa fil \"{file}\" därför att den redan existerar",
    "Could not create folder \"{dir}\" because it already exists" : "Kunde inte skapa \"{dir}\" därför att den redan existerar",
    "Error deleting file \"{fileName}\"." : "Fel när \"{fileName}\" skulle raderas.",
    "No search results in other folders for {tag}{filter}{endtag}" : "Inga sökresultat i andra mappar för {tag}{filter}{endtag}",
    "Name" : "Namn",
    "Size" : "Storlek",
    "Modified" : "Ändrad",
    "_%n folder_::_%n folders_" : ["%n mapp","%n mappar"],
    "_%n file_::_%n files_" : ["%n fil","%n filer"],
    "{dirs} and {files}" : "{dirs} och {files}",
    "_including %n hidden_::_including %n hidden_" : ["inkluderar %n gömd","inkluderar %n gömda"],
    "You don’t have permission to upload or create files here" : "Du har ej tillåtelse att ladda upp eller skapa filer här",
    "_Uploading %n file_::_Uploading %n files_" : ["Laddar upp %n fil","Laddar upp %n filer"],
    "New" : "Ny",
    "\"{name}\" is an invalid file name." : "\"{name}\" är ett ogiltigt filnamn.",
    "File name cannot be empty." : "Filnamn kan inte vara tomt.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" är inte en tillåten filtyp",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Lagring av {owner}  är full, filer kan inte uppdateras eller synkroniseras längre!",
    "Your storage is full, files can not be updated or synced anymore!" : "Ditt lagringsutrymme är fullt, filer kan inte längre uppdateras eller synkroniseras!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Lagring av  {owner}  är nästan full  ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Ditt lagringsutrymme är nästan fullt ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["matchar '{filter}'","matcha '{filter}'"],
    "View in folder" : "Utforska i mapp",
    "Copied!" : "Kopierad!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopiera direktlänk (fungerar endast för de användare som har tillgång till denna fil eller mapp)",
    "Path" : "sökväg",
    "_%n byte_::_%n bytes_" : ["%n bytes","%n bytes"],
    "Favorited" : "Favoriserad",
    "Favorite" : "Favorit",
    "New folder" : "Ny mapp",
    "Upload file" : "Ladda upp fil",
    "Not favorited" : "Ej favoriserade",
    "Remove from favorites" : "Ta bort från favoriter",
    "Add to favorites" : "Lägg till i favoriter",
    "An error occurred while trying to update the tags" : "Ett fel uppstod när uppdatera taggarna",
    "Added to favorites" : "Lades till i favoriter",
    "Removed from favorites" : "Togs bort från favoriter",
    "You added {file} to your favorites" : "Du la till {file} till dina favoriter",
    "You removed {file} from your favorites" : "Du tog bort {file} från dina favoriter",
    "File changes" : "Filändringar",
    "Created by {user}" : "Skapad av {user}",
    "Changed by {user}" : "Ändrad av {user}",
    "Deleted by {user}" : "Raderad av {user}",
    "Restored by {user}" : "Återställd av {user}",
    "Renamed by {user}" : "Filnamn ändrat av {user}",
    "Moved by {user}" : "Flyttad av {user}",
    "\"remote user\"" : "\"extern användare\"",
    "You created {file}" : "Du skapade {file}",
    "{user} created {file}" : "{user} skapade {file}",
    "{file} was created in a public folder" : "{file} skapades i en offentlig mapp",
    "You changed {file}" : "Du ändrade {file}",
    "{user} changed {file}" : "{user} ändrade {file}",
    "You deleted {file}" : "Du raderade {file}",
    "{user} deleted {file}" : "{user} raderade {file}",
    "You restored {file}" : "Du återställde {file}",
    "{user} restored {file}" : "{user} återställde {file}",
    "You renamed {oldfile} to {newfile}" : "Du ändrade filnamn {oldfile} till {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} ändrade filnamn {oldfile} till {newfile}",
    "You moved {oldfile} to {newfile}" : "Du flyttade {oldfile} till {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} flyttade {oldfile} till {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "En fil har lagts till eller tagits bort från dina <strong>favoriter</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "En fil har blivit <strong>ändrad</strong> eller <strong>bytt namn</strong>",
    "A new file or folder has been <strong>created</strong>" : "En ny fil eller mapp har blivit <strong>skapad</strong>",
    "A file or folder has been <strong>deleted</strong>" : "En fil eller mapp har <strong>tagits bort</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Begränsa notiser om skapande och ändringar till dina <strong>favoritfiler</strong> <em>(Endast i flödet)</em>",
    "A file or folder has been <strong>restored</strong>" : "En fil eller mapp har <strong>återställts</strong>",
    "Unlimited" : "Obegränsad",
    "Upload (max. %s)" : "Ladda upp (max. %s)",
    "File handling" : "Filhantering",
    "Maximum upload size" : "Maximal storlek att ladda upp",
    "max. possible: " : "max. möjligt:",
    "Save" : "Spara",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Med PHP-FPM kan det ta cirka 5 minuter för ändringarna att träda i kraft.",
    "Missing permissions to edit from here." : "Saknar rättigheter att ändra härifrån.",
    "%s of %s used" : "%s av %s använt",
    "%s used" : "%s använt",
    "Settings" : "Inställningar",
    "Show hidden files" : "Visa dolda filer",
    "WebDAV" : "WebDAV",
    "Cancel upload" : "Avbryt uppladdning",
    "No files in here" : "Inga filer kunde hittas",
    "Upload some content or sync with your devices!" : "Ladda upp innehåll eller synkronisera med dina enheter!",
    "No entries found in this folder" : "Inget innehåll hittades i denna mapp",
    "Select all" : "Välj allt",
    "Upload too large" : "För stor uppladdning",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Filerna du försöker ladda upp överstiger den maximala storleken för filöverföringar på servern.",
    "No favorites yet" : "Inga favoriter ännu",
    "Files and folders you mark as favorite will show up here" : "Filer och mappar markerade som favoriter kommer att visas här",
    "Shared with you" : "Delad med dig",
    "Shared with others" : "Delad med andra",
    "Shared by link" : "Delad via länk",
    "Tags" : "Taggar",
    "Deleted files" : "Raderade filer",
    "Text file" : "Textfil",
    "New text file.txt" : "nytextfil.txt",
    "Uploading..." : "Laddar upp...",
    "..." : "...",
    "_{hours}:{minutes}:{seconds} hour left_::_{hours}:{minutes}:{seconds} hours left_" : ["{hours}:{minutes}:{seconds} timme kvar","{hours}:{minutes}:{seconds} timmar kvar"],
    "{hours}:{minutes}h" : "{hours}:{minutes}",
    "_{minutes}:{seconds} minute left_::_{minutes}:{seconds} minutes left_" : ["{minutes}:{seconds} minut kvar","{minutes}:{seconds} minuter kvar"],
    "{minutes}:{seconds}m" : "{minutes}:{seconds}",
    "_{seconds} second left_::_{seconds} seconds left_" : ["{seconds} sekund kvar","{seconds} sekunder kvar"],
    "{seconds}s" : "{seconds}s",
    "Any moment now..." : "Alldeles strax...",
    "Soon..." : "Snart...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Filuppladdning pågår. Lämnar du sidan så avbryts uppladdningen.",
    "Move" : "Flytta",
    "Copy local link" : "Kopiera den lokala länken",
    "Folder" : "Mapp",
    "Upload" : "Ladda upp",
    "A new file or folder has been <strong>deleted</strong>" : "En ny fil har blivit <strong>raderad</strong>",
    "A new file or folder has been <strong>restored</strong>" : "En ny fil eller mapp har blivit <strong>återställd</strong>",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Använd den här adressen för att <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">komma åt dina filer via WebDAV</a>",
    "No favorites" : "Inga favoriter"
},
"nplurals=2; plural=(n != 1);");
